#ifndef DAC161_H_
#define DAC161_H_
/*************************************************************************************************************************************************/
/*!     DAC161.h
*
*       Header file for DAC161.c library software
*
*       October 2013
*
*/
/**************************************************************************************************************************************************
*       Copyright  2013 Texas Instruments Incorporated - http://www.ti.com/                                                                      *
***************************************************************************************************************************************************
*  Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met: *
*                                                                                                                                                 *
*    Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.                 *
*                                                                                                                                                 *
*    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the        *
*    documentation and/or other materials provided with the distribution.                                                                         *
*                                                                                                                                                 *
*    Neither the name of Texas Instruments Incorporated nor the names of its contributors may be used to endorse or promote products derived      *
*    from this software without specific prior written permission.                                                                                *
*                                                                                                                                                 *
*  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT          *
*  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT     *
*  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT         *
*  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY    *
*  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE      *
*  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.                                                                           *
**************************************************************************************************************************************************/


#define DAC161_XFER_REG                     0x01
#define DAC161_NOP_REG                      0x02
#define DAC161_WR_MODE_REG                  0x03
#define DAC161_DACCODE_REG                  0x04
#define DAC161_ERR_CONFIG_REG               0x05
#define DAC161_ERR_LOW_REG                  0x06
#define DAC161_ERR_HIGH_REG                 0x07
#define DAC161_RESET_REG                    0x08
#define DAC161_STATUS_REG                   0x09


#define DAC161_SPI_WRITE_CMD(address)       (address)
#define DAC161_SPI_READ_CMD(address)        (0x80 + address)


// XFER_REG Register Settings - 01h
#define DAC161_XFER_REG_CMD                 0x00FF

// WR_MODE Register Settings - 03h
#define DAC161_PROTECT_REG_WR               0x0001

//  DACCODE Register Settings - 04h
#define DAC161_OUTPUT_CONVERT(uA)           (((unsigned long)uA * 2732) / 1000)

// ERR_CONFIG Register Settings - 05h
#define DAC161_L_RETRY_TIME_MASK            0x0700
#define DAC161_L_RETRY_TIME_SHIFT           8

#define DAC161_CONVERT_LOOP_RETRY_TIME(ms)  ((((ms / 50) - 1) << DAC161_L_RETRY_TIME_SHIFT) & DAC161_L_RETRY_TIME_MASK)

#define DAC161_DIS_RETRY_LOOP_MASK          0x0080
#define DAC161_DISABLE_RETRY_LOOP           0x0080
#define DAC161_ENABLE_RETRY_LOOP            0x0000

#define DAC161_MASK_LOOP_ERR_MASK           0x0040
#define DAC161_LOOP_ERR_USE_ERR_LOW         0x0000
#define DAC161_LOOP_ERR_MAINTAIN_DACCODE    0x0040

#define DAC161_LOOP_ERR_ERRB_MASK           0x0020
#define DAC161_LOOP_ERR_DRIVE_ERRB          0x0000
#define DAC161_LOOP_ERR_DO_NOT_DRIVE_ERRB   0x0020

#define DAC161_MASK_SPI_ERR                 0x0010

#define DAC161_SPI_TIMEOUT_MASK             0x000e
#define DAC161_SPI_TIMEOUT_SHIFT            1
#define DAC161_CONVERT_SPI_TIMEOUT_TIME(ms) ((((ms / 50) - 1) << DAC161_SPI_TIMEOUT_SHIFT) & DAC161_SPI_TIMEOUT_MASK)

#define DAC161_MASK_SPI_TIMEOUT             0x0001

#define DAC161_STD_ERR_CONFIG_MASKED        (DAC161_DISABLE_RETRY_LOOP + DAC161_LOOP_ERR_MAINTAIN_DACCODE + DAC161_LOOP_ERR_DO_NOT_DRIVE_ERRB + DAC161_MASK_SPI_ERR + DAC161_MASK_SPI_TIMEOUT)
#define DAC161_STD_ERR_CONFIG               ((1 << DAC161_L_RETRY_TIME_SHIFT) + DAC161_ENABLE_RETRY_LOOP + DAC161_LOOP_ERR_USE_ERR_LOW + DAC161_LOOP_ERR_DRIVE_ERRB + (4 << DAC161_SPI_TIMEOUT_SHIFT) + DAC161_MASK_SPI_TIMEOUT)

// ERR_LOW Register Settings  - 06h and
// ERR_HIGH Register Settings - 07h and

#define DAC161_ERR_VALUE_MASK               0xff00
#define DAC161_ERR_VALUE_SHIFT              8
#define DAC161_CONVERT_ERR_VALUE(uA)        ((DAC161_OUTPUT_CONVERT(uA) & DAC161_ERR_VALUE_MASK))

// RESET Register Settings  - 08h
#define DAC161_RESET_VALUE                  0xc33c         // Note that a NOP command is required after this

// STATUS Register Settings  - 09h
#define DAC161_DAC_RES_MASK                 0x00e0
#define DAC161_DAC_RES_SHIFT                5

#define DAC161_ERRLVL_PIN                   0x0010

#define DAC161_FERR_STS                     0x0008

#define DAC161_SPI_TIMEOUT_ERR              0x0004

#define DAC161_LOOP_STS                     0x0002

#define DAC161_CURR_LOOP_STS                0x0001



/*************************************************************************************************************/
/*                              PROTOTYPES                                                                   */
/*************************************************************************************************************/

#ifdef __CPLUSPLUS
extern "C" {
#endif

void DAC161_Write_Regs (unsigned short *writeValues, unsigned char startReg, unsigned char lengthBytes);
void DAC161_Read_Regs (unsigned char *readValues, unsigned char startReg, unsigned char lengthBytes);
void Setup_DAC161  (Port_t ste_port, unsigned char ste_pin, unsigned short errConfig, unsigned short errLow_uA, unsigned short errHigh_uA);
void DAC161_Reset (void);
void DAC161_Nop (void);
void DAC161_Set_Out_Value (unsigned long uAmps);
unsigned char DAC161_Read_Status (void);

#ifdef __CPLUSPLUS
}
#endif


#endif /* DAC161_H_ */
